<?php
/***************************************************************************
 * $Id: phpbb2.class.php 53 2008-05-01 16:23:36Z Nico $
 * Part of Parsimony Import
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include_once 'phpbb-basis.class.php';

class phpBB2Import extends phpBBBasisImport {
	
	var $forumID = null;
	var $topicsAdded = array();
	var $bbCodeUID = 'd36eb7da09';
	
	function phpBB2Import ( $directory, $host, $user, $pass, $db, $forumID, $prefix = 'phpbb_', $useXAJAX = false, $debug = false ) {
		$this->phpBBBasisImport( $directory, $host, $user, $pass, $db, (int)$forumID, $prefix, $useXAJAX, $debug );

		if ( $this->hasAlert() ) {
			return;
		}
		
		// Check if table exists
		$this->checkTableExistance( $this->prefix . 'posts_text' );
	}
	
	function prepareForDebug () {
		$this->database->sql_truncate ( array ( $this->prefix . 'topics', $this->prefix . 'posts', $this->prefix . 'posts_text' ) );
	}
	
	function insertNewTopic ( $title, $posterName, $time ) {
		if ( $this->forumID == null ) {
			$this->alert( 'Please set a forumID before starting the import!' );
		}
		
		$insertArray = array (	'topic_title' => $title,
								'topic_poster' => -1,
								'topic_time' => $time,
								'forum_id' => $this->forumID,
								'topic_status' => 0,
								'topic_type' => 0,
								'topic_vote' => 0,
								'topic_first_post_id' => 0 );
		
		$this->database->sql_insert ( $this->prefix . 'topics', $insertArray );
		$this->actualTopicID = $this->database->sql_getID();
		$this->topicsAdded[] = $this->actualTopicID;
		return $this->actualTopicID;
	}
	
	function insertPosting ( $topicID, $posterName, $title, $text, $time ) {
		$insertArray = array (	'topic_id' => $topicID,
								'forum_id' => $this->forumID,
								'poster_id' => -1,
								'post_username' => $posterName,
								'post_time' => $time,
								'poster_ip' => '3e2f1823', 
								'enable_bbcode' => 1,
								'enable_html' => 0,
								'enable_smilies' => 1,
								'enable_sig' => 0 );		
		$this->database->sql_insert ( $this->prefix . 'posts', $insertArray );
        $this->lastPosting = $this->database->sql_getID();

        $text = $this->generateBB($text);
        $insertArray = array ( 	'post_id' => $this->lastPosting,
        						'post_subject' => $title,
        						'bbcode_uid' => $this->bbCodeUID,
        						'post_text' => $text );
        $this->database->sql_insert ( $this->prefix . 'posts_text', $insertArray );
        
        $this->actualTopicID = $topicID;
       	
        return $this->lastPosting;
	}
	
	function finally() {
		// synchronize inserted topics
		$sql = 'SELECT t.topic_id, count( p.post_id ) AS cp, t.topic_replies AS tr,
			MAX(p.post_id) AS last_post, MIN(p.post_id) AS first_post
			FROM ' . $this->prefix . 'topics t LEFT JOIN ' . $this->prefix . 'posts p
			ON t.topic_id = p.topic_id WHERE t.forum_id = ' . $this->forumID . ' GROUP BY t.topic_id';
		$result = $this->database->sql_query ( $sql );
		while ( $topicToUpdate = $this->database->sql_row ( $result ) ) {
			$updateArray = array (	'topic_replies' => (int)$topicToUpdate['cp'] - 1,
									'topic_first_post_id' => (int)$topicToUpdate['first_post'],
									'topic_last_post_id' => (int)$topicToUpdate['last_post']);
			$this->database->sql_update ( $this->prefix . 'topics', $updateArray, array ( 'topic_id' => (int)$topicToUpdate['topic_id'] ) );
		}
		
		// synchronize forum
		// borrowed from includes/functions_admin.php of phpBB 2.0.23
		$sql = "SELECT MAX(post_id) AS last_post, COUNT(post_id) AS total
				FROM " . $this->prefix . "posts WHERE forum_id = $this->forumID";
		$result = $this->database->sql_query($sql);
			
		if ( $row = $this->database->sql_row($result) )
		{
			$last_post = ( $row['last_post'] ) ? $row['last_post'] : 0;
			$total_posts = ($row['total']) ? $row['total'] : 0;
		}
		else
		{
			$last_post = 0;
			$total_posts = 0;
		}

		$sql = "SELECT COUNT(topic_id) AS total FROM " . $this->prefix . "topics
			WHERE forum_id = $this->forumID";
		$result = $this->database->sql_query($sql);

		$total_topics = ( $row = $this->database->sql_row($result) ) ? ( ( $row['total'] ) ? $row['total'] : 0 ) : 0;

		$updateArray = array (	'forum_last_post_id' => (int)$last_post,
								'forum_posts' => (int)$total_posts,
								'forum_topics' => (int)$total_topics);
		$this->database->sql_update ( $this->prefix . 'forums', $updateArray, array ('forum_id' => $this->forumID ) );
	}
}
?>