<?php
/***************************************************************************
 * $Id: smf1.class.php 53 2008-05-01 16:23:36Z Nico $
 * Part of Parsimony Import
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

class SMF1Import extends basisImport   {
	
	var $forumID = null;
	var $topicsAdded = array();
	var $bbCodeUID = 'd36eb7da';
	var $prefix = '';
	
	function SMF1Import ( $directory, $host, $user, $pass, $db, $forumID, $prefix = 'smf_', $useXAJAX = false, $debug = false ) {
		$this->basisImport( $directory, $host, $user, $pass, $db, $useXAJAX, $debug );	
		
		if ( $this->hasAlert() ) {
			return;
		}		
		
		$this->forumID = (int)$forumID;
		$this->prefix = $prefix;
		
		// Check if tables exist
		$this->checkTableExistance( $this->prefix . 'boards' );
		$this->checkTableExistance( $this->prefix . 'topics' );
		$this->checkTableExistance( $this->prefix . 'messages' );
	}
	
	function prepareForDebug () {
		$this->database->sql_truncate ( array ( $this->prefix . 'topics', $this->prefix . 'messages' ) );
	}	
	
	function insertNewTopic ( $title, $posterName, $time ) {
		// empty here - inserting is done in insertPosting
		return -1;
	}
	
	function insertPosting ( $topicID, $posterName, $title, $text, $time ) {
		$text = $this->generateBB($text);
		
		$insertArray = array ( 	'ID_TOPIC' => (int)$topicID,
								'ID_BOARD' => (int)$this->forumID,
								'posterTime' => $time,
								'ID_MEMBER' => 0,
								'subject' => $title,
								'posterName' => $posterName,
								'smileysEnabled' => 1,
								'body' => $text );
		$this->database->sql_insert ( $this->prefix . 'messages', $insertArray );
		
        $this->lastPosting = $this->database->sql_getID();
		
		if ( $topicID == -1 ) {
			// There is still a topic to add!
		
			$insertArray = array(	'ID_BOARD' => $this->forumID,
									'ID_MEMBER_STARTED' => 0,
									'ID_MEMBER_UPDATED' => 0,
									'ID_FIRST_MSG' => (int)$this->lastPosting,
									'ID_LAST_MSG' => (int)$this->lastPosting );
			$this->database->sql_insert ( $this->prefix . 'topics', $insertArray );
		
			$this->actualTopicID = $this->database->sql_getID();
			$this->topicsAdded[] = $this->actualTopicID;
			$this->database->sql_update ( $this->prefix . 'messages', array ( 'ID_TOPIC' => $this->actualTopicID ), array ( 'ID_MSG' => $this->lastPosting ) );
		} else {
			$this->actualTopicID = $topicID;
		}

        return $this->lastPosting;
	}
	
	function generateBB ( $text ) {
		$text = $this->generateQuote( $text );
		$text = preg_replace ( "@&amp;lt;i&amp;gt;(.*?)&amp;lt;/i&amp;gt;@s", "[i]$1[/i]", $text );
		
		$text = str_replace ( array ( "&amp;lt;", "&amp;gt;" ), array ( "&lt;", "&gt;" ), $text );
		return $text;
	}	
	
	function generateQuote ( $message ) {
		$messageArray = explode ( "\n", $message );
		$inQuote = false;
		$beforeQuoteArray = array();
		$quoteArray = array();
		$afterQuoteArray = array();
		foreach ( $messageArray as $singleLine ) {
			if ( substr ( $singleLine, 0, 4 ) == '&gt;' ) {
				$quoteArray[] = substr ( $singleLine, 4 );
				$inQuote = true;
			} elseif ( $inQuote ) {
				$afterQuoteArray[] = $singleLine;
			} else {
				$beforeQuoteArray[] = $singleLine;
			}
		}
		$messageReturn = '';
		if ( count ( $beforeQuoteArray ) > 0 ) {
			$messageReturn .= implode ( "\n", $beforeQuoteArray );
		}
		if ( count ( $quoteArray ) > 0 ) {
			$messageReturn .= '[quote]' . $this->generateQuote( implode ( "\n", $quoteArray ) ) . '[/quote]';
		}
		if ( count ( $afterQuoteArray ) > 0 ) {
			$messageReturn .= $this->generateQuote(implode ( "\n", $afterQuoteArray ) );
		}
		return $messageReturn;
	}	
	
	function finally() {
		// synchronize inserted topics
		$sql = 'SELECT t.ID_TOPIC, count( m.ID_MSG ) AS cp,
			MAX(m.ID_MSG) AS last_post, MIN(m.ID_MSG) AS first_post
			FROM ' . $this->prefix . 'topics t LEFT JOIN ' . $this->prefix . 'messages m
			ON t.ID_TOPIC = m.ID_TOPIC WHERE t.ID_BOARD = ' . $this->forumID . ' GROUP BY t.ID_TOPIC';
		$result = $this->database->sql_query ( $sql );
		$topicCount = $this->database->sql_numrows ( $result );
		while ( $topicToUpdate = $this->database->sql_row ( $result ) ) {
			$updateArray = array (	'numReplies' => (int)$topicToUpdate['cp'] - 1,
									'ID_FIRST_MSG' => (int)$topicToUpdate['first_post'],
									'ID_LAST_MSG' => (int)$topicToUpdate['last_post']);
			$this->database->sql_update ( $this->prefix . 'topics', $updateArray, array ( 'ID_TOPIC' => (int)$topicToUpdate['ID_TOPIC'] ) );	
		}

		$sql = 'SELECT ID_MSG FROM ' . $this->prefix . 'messages WHERE ID_BOARD = ' . $this->forumID . ' ORDER BY posterTime DESC LIMIT 0, 1';
		$result = $this->database->sql_query ( $sql );
		$lastMessageRow = $this->database->sql_row ( $result );
		$lastMessageID = (int)$lastMessageRow['ID_MSG'];
		
		$sql = 'SELECT COUNT(ID_MSG) as countPosts FROM ' . $this->prefix	. 'messages WHERE ID_BOARD = ' . $this->forumID;
		$result = $this->database->sql_query ( $sql );
		$postCountRow = $this->database->sql_row ( $result );
		$postCount = (int)$postCountRow['countPosts'];		
		
		$updateArray = array (	'numTopics' => $topicCount,
								'numPosts' => $postCount,
								'ID_LAST_MSG' => $lastMessageID);
		$this->database->sql_update ( $this->prefix . 'boards', $updateArray, array ('ID_BOARD' => $this->forumID ) );
		
	}
}
?>